/****************************************************************************/
/*	Copyright (c) 2009, Bendor Research Pty. Ltd. All rights reserved.		*/
/*	This software is released under the GNU General Public License, version	*/
/*	3, with the exemptions that 1) the header files installed by this 	 	*/
/*	package can be included in closed-source code and 2) the libraries		*/
/*	built by this package can be statically linked into a closed-source 	*/
/*	binary. See the file LICENSE for the details.							*/
/*	This software is provided "AS IS", without any warranty or guarantee.	*/
/*	By using this software you acknowledge that neither Bendor Research nor	*/
/*	any of its personnel or affiliates can be held liable for any damages,	*/
/*	including, but not limited to, loss of business, loss of money, loss of */
/*	life, loss of reputation, arising out of this software being faulty or	*/
/*	not performing as advertised, even if Bendor Research was aware of such	*/
/*	faults in the software. You use this software at your own risk, any and */
/*	all liabilities that arise out of your using this software are strictly	*/
/*	yours.																	*/
/****************************************************************************/

#include <misc/dlink.h>

/** @addtogroup misc_dll */
/**	@{ */

/**
*	Cuts a list into two.
*
*	The list will be cut at the given element in such a way that the
*	second list will start with the given element and the first will
*	end with the element before the given one.
*
*	@param	list1	Pointer to the list to cut
*	@param	list2	Pointer to the second list (should be empty)
*	@param	refp	Pointer to the element that will start the second list
*/

void	DL_Cut( DLLIST *list1, DLLIST *list2, DLLINK *refp )
{
	list2->head = refp;
	list2->tail = list1->tail;

	if ( ( list1->tail = refp->prev ) )

		list1->tail->next = (void *) 0;
	else
		list1->head = (void *) 0;

	refp->prev = (void *) 0;
}

/** @} */

